@@ -9,7 +9,7 @@ import time
 from motordecalidad.rules import *
 
 
-print("Motor de Calidad Version Release 1.9.1")
+print("Motor de Calidad Version Release 1.9.2")
 
 # Main function, Invokes all the parameters from the json, Optionally filters, starts the rule validation
 # Writes and returns the summary of the validation 
@@ -487,18 +487,18 @@ def validateRules(object:DataFrame,rules:dict,registerAmount:int, entity: str, p
                 column = rules[code].get(JsonParts.Fields)
                 if column[0] == "*" :
                     res = measuresCentralTendency(object, object.columns, spark)
-                    writeDf(res,rules[code].get(JsonParts.Output),"estadisticas.csv")
+                    writeDf(res,rules[code].get(JsonParts.Output))
                 else:
                     res = measuresCentralTendency(object, column,spark)
-                    writeDf(res,rules[code].get(JsonParts.Output),"estadisticas.csv")
+                    writeDf(res,rules[code].get(JsonParts.Output))
         else:
             pass
     if errorData.count() > Zero:
-        writeDf(errorData,error,"error.csv")
+        writeDf(errorData,error)
     try:
         if validData == "TRUE":
             finalData = object.join(errorData,on = Data.get(JsonParts.Fields), how = LeftAntiType)
-            writeDf(finalData,Data,rulesNumber,"data,csv")
+            writeDf(finalData,Data,rulesNumber)
     except:
         pass
     validationData:DataFrame = spark.createDataFrame(data = rulesData, schema = OutputDataFrameColumns)
