@@ -231,14 +231,31 @@ def validateDataType(object:DataFrame,
     data_Type:str):
 
     dataRequirement =  f"El atributo {entity}.{columnName}, debe ser de tipo {data_Type}"
-
-    if str(object.schema[columnName].dataType) == data_Type:
-        ratio = 0.0
-        errorCount = 0
-        
-    else:
-        ratio = 100.0
-        errorCount = object.count()
+    try:
+        if str(object.schema[columnName].dataType) == data_Type:
+            ratio = 0.0
+            errorCount = 0
+            
+        else:
+            ratio = 100.0
+            errorCount = object.count()
+    except:
+        try:
+            if str(object.schema[columnName.upper()].dataType) == data_Type:
+                ratio = 0.0
+                errorCount = 0
+            
+            else:
+                ratio = 100.0
+                errorCount = object.count()
+        except:
+            if str(object.schema[columnName.lower()].dataType) == data_Type:
+                ratio = 0.0
+                errorCount = 0
+            
+            else:
+                ratio = 100.0
+                errorCount = object.count()
 
     return [registerAmount, Rules.DataTypeRule.code,Rules.DataTypeRule.name,Rules.DataTypeRule.property,Rules.DataTypeRule.code + "/" + entity + "/" + columnName,threshold,dataRequirement, columnName, ratio, errorCount]
 
